;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "kirigami" "20251202.1126"
  "A unified method to fold and unfold text."
  '((emacs "26.3"))
  :url "https://github.com/jamescherti/kirigami.el"
  :commit "b23cae12111dd193b968d6e319dff8131e7796b0"
  :revdesc "b23cae12111d"
  :keywords '("convenience"))
